package com.sun.org.apache.xml.internal.security.utils;

import com.sun.org.slf4j.internal.LoggerFactory;
import com.sun.org.apache.xml.internal.security.signature.XMLSignatureException;
import com.sun.org.apache.xml.internal.security.algorithms.SignatureAlgorithm;
import com.sun.org.slf4j.internal.Logger;
import java.io.ByteArrayOutputStream;

public class SignerOutputStream extends ByteArrayOutputStream
{
    private static final Logger LOG;
    final SignatureAlgorithm sa;
    
    public SignerOutputStream(SignatureAlgorithm sa) {
        this.sa = sa;
    }
    
    @Override
    public void write(byte[] input) {
        try {
            this.sa.update(input);
        }
        catch (XMLSignatureException obj) {
            throw new RuntimeException("" + obj);
        }
    }
    
    @Override
    public void write(int n) {
        try {
            this.sa.update((byte)n);
        }
        catch (XMLSignatureException obj) {
            throw new RuntimeException("" + obj);
        }
    }
    
    @Override
    public void write(byte[] buf, int i, int n) {
        if (SignerOutputStream.LOG.isDebugEnabled()) {
            SignerOutputStream.LOG.debug("Canonicalized SignedInfo:");
            StringBuilder sb = new StringBuilder(n);
            for (; i < i + n; ++i) {
                sb.append((char)buf[i]);
            }
            SignerOutputStream.LOG.debug(sb.toString());
        }
        try {
            this.sa.update(buf, i, n);
        }
        catch (XMLSignatureException obj) {
            throw new RuntimeException("" + obj);
        }
    }
    
    static {
        LOG = LoggerFactory.getLogger(SignerOutputStream.class);
    }
}
